@@ -26,12 +26,16 @@ rlang::`%||%`
 rlang::`%|%`
 
 #' @export
-#' @importFrom tibble tibble
-tibble::tibble
+#' @importFrom ipmisc tibble
+ipmisc::tibble
 
 #' @export
-#' @importFrom tibble as_tibble
-tibble::as_tibble
+#' @importFrom ipmisc enframe
+ipmisc::enframe
+
+#' @export
+#' @importFrom ipmisc as_tibble
+ipmisc::as_tibble
 
 
 # ----------------------- ipmisc -----------------------------------
